@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdE.c,v 1.4 2010/06/17 14:38:33 tim Exp $";
+static const char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/commands/CmdE.c,v 1.4 2010/06/17 14:38:33 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -79,15 +79,15 @@ static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/
 static bool cmdFoundNewEdit;
 
 void
-CmdEdit(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdEdit(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     Rect area, pointArea;
     CellUse *usave, *use = NULL;
     CellDef *csave;
-    int cmdEditRedisplayFunc();		/* Forward declaration. */
-    int cmdEditEnumFunc();		/* Forward declaration. */
+    int cmdEditRedisplayFunc(MagWindow *w, Rect *area);		/* Forward declaration. */
+    int cmdEditEnumFunc(CellUse *selUse, CellUse *use, Transform *transform, Rect *area);		/* Forward declaration. */
     bool noCurrentUse = FALSE;
 
     if ((w != NULL) && (cmd->tx_argc == 2))
@@ -197,11 +197,11 @@ CmdEdit(w, cmd)
  */
 
 int
-cmdEditRedisplayFunc(w, area)
-    MagWindow *w;			/* Window containing edit cell. */
-    Rect *area;			/* Area to be redisplayed. */
+cmdEditRedisplayFunc(
+    MagWindow *w,			/* Window containing edit cell. */
+    Rect *area)			/* Area to be redisplayed. */
 {
-    static Rect origin = {{-1, -1}, {1, 1}};
+    static const Rect origin = {{-1, -1}, {1, 1}};
     Rect tmp;
     DBWclientRec *crec = (DBWclientRec *) w->w_clientData;
 
@@ -226,13 +226,13 @@ cmdEditRedisplayFunc(w, area)
  */
 
 int
-cmdEditEnumFunc(selUse, use, transform, area)
-    CellUse *selUse;		/* Use from selection (not used). */
-    CellUse *use;		/* Use from layout that corresponds to
+cmdEditEnumFunc(
+    CellUse *selUse,		/* Use from selection (not used). */
+    CellUse *use,		/* Use from layout that corresponds to
 				 * selUse (could be an array!).
 				 */
-    Transform *transform;	/* Transform from use->cu_def to root coords. */
-    Rect *area;			/* We're looking for a use containing this
+    Transform *transform,	/* Transform from use->cu_def to root coords. */
+    Rect *area)			/* We're looking for a use containing this
 				 * area, in root coords.
 				 */
 {
@@ -305,20 +305,20 @@ cmdEditEnumFunc(selUse, use, transform, area)
 #define OPTION_FLAGS	3
 
 void
-CmdElement(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdElement(
+    MagWindow *w,
+    TxCommand *cmd)
 {
 
     int option, type;
-    char **msg;
+    const char * const *msg;
     Rect area;
     int style;
     CellDef *def;
     CellUse *use;
     bool getopt;
 
-    static char *cmdElementOption[] = {
+    static const char * const cmdElementOption[] = {
 	"add			create a new element",
 	"delete		delete an existing element",
 	"configure		configure or query an existing element",
@@ -328,14 +328,14 @@ CmdElement(w, cmd)
 	NULL
     };
 
-    static char *cmdElementType[] = {
+    static const char * const cmdElementType[] = {
 	"line		name style x1 y1 x2 y2",
 	"rectangle		name style llx lly urx ury",
 	"text		name style cx cy label",
 	NULL
     };
 
-    static char *cmdConfigureType[] = {
+    static const char * const cmdConfigureType[] = {
 	"text		get (or) replace <string>",
 	"style		get (or) add <style> (or) remove <style>",
 	"position		get (or) <point> (or) <rect>",
@@ -627,13 +627,13 @@ static CellUse *cmdEraseCells[MAXCELLS];
 static int cmdEraseCount;
 
 void
-CmdErase(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdErase(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     Rect editRect, areaReturn;
     TileTypeBitMask mask, errorLayersForErasure, activeLayersForErasure;
-    extern int cmdEraseCellsFunc();
+    extern int cmdEraseCellsFunc(SearchContext *scx, ClientData cdarg);
 
     windCheckOnlyWindow(&w, DBWclientID);
     if (w == (MagWindow *) NULL) return;
@@ -759,9 +759,9 @@ CmdErase(w, cmd)
 }
 
 int
-cmdEraseCellsFunc(scx, cdarg)
-SearchContext *scx;		/* Indicates cell found. */
-ClientData cdarg;		/* Not used. */
+cmdEraseCellsFunc(
+    SearchContext *scx,		/* Indicates cell found. */
+    ClientData cdarg)		/* Not used. */
 {
     /* All this procedure does is to remember cells that are
      * found, up to MAXCELLS of them.
@@ -797,15 +797,15 @@ ClientData cdarg;		/* Not used. */
  */
 
 void
-CmdExpand(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdExpand(
+    MagWindow *w,
+    TxCommand *cmd)
 {
     int windowMask, boxMask, d;
     Rect rootRect;
     CellUse *rootBoxUse;
     CellDef *rootBoxDef;
-    int cmdExpandFunc();		/* Forward reference. */
+    int cmdExpandFunc(CellUse *use, int windowMask);		/* Forward reference. */
 
     if (cmd->tx_argc > 2 || (cmd->tx_argc == 2
 	&& (strncmp(cmd->tx_argv[1], "toggle", strlen(cmd->tx_argv[1])) != 0)))
@@ -869,9 +869,9 @@ CmdExpand(w, cmd)
  */
 
 int
-cmdExpandFunc(use, windowMask)
-    CellUse *use;		/* Use that was just expanded. */
-    int windowMask;		/* Window where it was expanded. */
+cmdExpandFunc(
+    CellUse *use,		/* Use that was just expanded. */
+    int windowMask)		/* Window where it was expanded. */
 {
     if (use->cu_parent == NULL) return 0;
     DBWAreaChanged(use->cu_parent, &use->cu_bbox, windowMask,
@@ -941,11 +941,12 @@ cmdExpandFunc(use, windowMask)
 #define UNIQNOTOPPORTS	3
 
 void
-CmdExtract(w, cmd)
-    MagWindow *w;
-    TxCommand *cmd;
+CmdExtract(
+    MagWindow *w,
+    TxCommand *cmd)
 {
-    char **msg, *namep, *arg;
+    const char * const *msg;
+    char *namep, *arg;
     int option, warn, len, n, all;
     int dist;
     bool no;
@@ -957,7 +958,7 @@ CmdExtract(w, cmd)
     int argc = cmd->tx_argc;
     char **argv = cmd->tx_argv;
 
-    static char *cmdExtWarn[] =
+    static const char * const cmdExtWarn[] =
     {
 	"all			enable all warnings",
 	"dup			warn when different nodes have the same name",
@@ -965,7 +966,7 @@ CmdExtract(w, cmd)
 	"labels		warn when subcell nodes are unlabelled",
 	NULL
     };
-    static char *cmdExtOption[] =
+    static const char * const cmdExtOption[] =
     {
 	"adjust			compensate R and C hierarchically",
 	"all			all options",
@@ -978,7 +979,7 @@ CmdExtract(w, cmd)
 	"aliases		output all net name aliases",
 	NULL
     };
-    static char *cmdExtLength[] =
+    static const char * const cmdExtLength[] =
     {
 	"clear			clear the driver and receiver tables",
 	"driver termName(s)	identify a driving (output) terminal",
@@ -988,7 +989,7 @@ CmdExtract(w, cmd)
 
     /* These must match definitions EXT_UNIQ_* in extract/extract.h: */
 
-    static char *cmdExtUniq[] =
+    static const char * const cmdExtUniq[] =
     {
 	"all			extract matching labels as unique nodes",
 	"#			extract tagged labels as unique nodes",
@@ -996,7 +997,7 @@ CmdExtract(w, cmd)
 	"notopports		ignore top-level ports when making labels unique",
 	NULL
     };
-    static char *cmdExtCmd[] =
+    static const char * const cmdExtCmd[] =
     {
 	"all			extract root cell and all its children",
 	"cell name		extract selected cell into file \"name\"",
