@@ -805,6 +805,7 @@ spcdevHierVisit(
 	case DEV_SUBCKT:
 	case DEV_RSUBCKT:
 	case DEV_CSUBCKT:
+	case DEV_DSUBCKT:
 	case DEV_MSUBCKT:
 	    devchar = 'X';
 	    break;
@@ -842,6 +843,7 @@ spcdevHierVisit(
 	    case DEV_VERILOGA:
 	    case DEV_RSUBCKT:
 	    case DEV_CSUBCKT:
+	    case DEV_DSUBCKT:
 	    case DEV_MSUBCKT:
 		fprintf(esSpiceF, "%d", esSbckNum++);
 		break;
@@ -884,6 +886,7 @@ spcdevHierVisit(
 	    break;
 
 	case DEV_MSUBCKT:
+	case DEV_DSUBCKT:
 	    /* msubcircuit is "Xnnn drain gate [source [sub]]]"		*/
 	    /* to more conveniently handle situations where MOSFETs	*/
 	    /* are modeled by subcircuits with the same pin ordering.	*/
@@ -912,7 +915,11 @@ spcdevHierVisit(
 	    /* except that the "gate" node is treated as an identifier	*/
 	    /* only and is not output.					*/
 
-        if (dev->dev_class != DEV_MSUBCKT)
+	    if (dev->dev_class == DEV_DSUBCKT)
+	    {
+		/* Do nothing;  both terminals have already been output */
+	    }
+	    else if (dev->dev_class != DEV_MSUBCKT)
 	    {
 		if (dev->dev_nterm > 1)
 		    spcdevOutNode(hc->hc_hierName, source->dterm_node->efnode_name->efnn_hier,
